@@ -64,12 +64,12 @@ class ParseTreeDrawable(ParseTree):
             self.reload()
 
     def save(self):
-        outputFile = open(self.__fileDescription.getFileName(), encoding="utf8")
+        outputFile = open(self.__fileDescription.getFileName(), mode='w', encoding="utf8")
         outputFile.write("(" + self.__str__() + ")\n")
         outputFile.close()
 
     def saveWithPath(self, newPath: str):
-        outputFile = open(self.__fileDescription.getFileName(newPath), encoding="utf8")
+        outputFile = open(self.__fileDescription.getFileName(newPath), mode='w', encoding="utf8")
         outputFile.write("(" + self.__str__() + ")\n")
         outputFile.close()
 
